@@ -139,7 +139,9 @@ impl WalkOptions {
             .process_read_dir(|_, _, _, dir_entry_results| {
                 dir_entry_results.iter_mut().for_each(|dir_entry_result| {
                     if let Ok(dir_entry) = dir_entry_result {
-                        dir_entry.client_state = Some(dir_entry.metadata());
+                        if dir_entry.file_type.is_file() || dir_entry.file_type().is_symlink() {
+                            dir_entry.client_state = Some(dir_entry.metadata());
+                        }
                     }
                 })
             })
